@@ -134,12 +134,3 @@ def get_dataframes(url = '', by_class= 'wikitable', table_indices= [], raw=False
             list_pds.append(df_table_values)
 
     return list_pds
-
-
-url= 'https://en.wikipedia.org/wiki/Israel_Adesanya'
-by_class= 'wikitable'
-table_indices=[6]
-raw= False
-dfs= get_dataframes(url, by_class, table_indices, raw)
-df= dfs[len(dfs)-1]
-print(dfs[len(dfs)-1])
